;;; -*- Mode: LISP; Syntax: Common-lisp; Package: CLIM-USER; Base: 10 -*-

;;;This code is a compilation of ideas and code from (at least) Oliver Christ
;;;<oli@adler.ims.uni-stuttgart.de>, Meir Laker <meir@watson.ibm.com>, Koenraad
;;;de Smedt <desmedt@ruls40.leidenuniv.nl> and myself.
;;;
;;;It creates a root window on quite a number of clim platforms and stores it
;;;in the *portable-root-window* variable.  It is CLIM 1.1.
;;;
;;;Send bugs, improvements and comments to <keunen@montefiore.ulg.ac.be>
;;;
;;;Vincent
;;;
;;;Keunen Vincent                  Network Research Belgium
;;;R&D, Software Engineer          Parc Industriel des Hauts-Sarts
;;;tel 32 41 407282                2e Avenue, 65
;;;fax 32 41 481170                BE-4040 Herstal, Belgium
;;;<keunen@montefiore.ulg.ac.be> or <keunen@nrb.be>

(in-package :clim-user)

(defvar *portable-root-window* nil)

(defun make-root-window ()
  "Stores a root window in *portable-root-window* (unless there is one already)
   and returns it."
  (unless (and (boundp '*portable-root-window*) *portable-root-window*)
    (setq *portable-root-window*
          
	  #+Lucid (open-root-window
                   :clx
                   :host (lcl:environment-variable "DISPLAY"))
	  #+Allegro-v4.1 (open-root-window
                          :clx
                          :host (system:getenv "DISPLAY"))
          #+Lispworks (open-root-window
                       :clx
                       :host (sys::getenv "DISPLAY"))
	  #+MCL          (open-root-window :mcl)
	  #+Genera       (when (equal "Symbolics Common Lisp"
				      (lisp-implementation-type))
			   (open-root-window :sheet))
	  #+Cloe         (when (equal "Symbolics Cloe"
				      (lisp-implementation-type))
			   (open-root-window :cloe))
	  ;;Please contact keunen@nrb.be if you modify this source code,
	  ;;for instance if you add new platforms support.  Thanks.
	  ))
  (or (and (boundp '*portable-root-window*) *portable-root-window*)
      (error "~2&Unknown CLIM/LISP combination.  Couldn't establish a root window!")))

(make-root-window)